==> blue2-buy-angus-theme-1.0.9-a94268.tar: src/Controllers/BusinessController.php <==
<?php

namespace Blue2\Scruffy\Controllers;

class BusinessController
{
    public function __construct()
    {
        $this->registerActions();
        $this->registerTaxonomy();
    }

    private function registerActions() {
        add_action('wp_head', [$this, 'loadGlobalVar']);
        add_action('wp_ajax_loadBusiness', [$this, 'loadBusinessAjaxHandler']);
        add_action('wp_ajax_nopriv_loadBusiness', [$this, 'loadBusinessAjaxHandler']);
        add_action('pre_get_posts', [$this, 'orderBusinesses']);
    }

    public static function registerTaxonomy()
    {
        $businessCategory = new \Blue2\Common\Taxonomy(
            "business-category",
            "Business Category",
            "Business Categories",
            "business",
            [
                'public' => true,
                'show_in_menu' => true,
                'show_admin_column' => true
            ]
        );
    }

    public function loadBusinessAjaxHandler()
    {
        $args['post_type'] = 'business';
        $args['post_status'] = 'publish';

        if (isset($_POST['searchPosts'])) {
            $args['s'] = $_POST['searchPosts'];
        }
        $args['tax_query'] = ['relation' => 'OR'];

        if (isset($_POST['term']) && $_POST['term'] != 'all' && $_POST['term'] != '') {
            $args['tax_query'][] = [
                [
                    'taxonomy' => 'business-category',
                    'field' => 'id',
                    'terms' => explode(",", $_POST['term']),
                ],
            ];
        }

        if (isset($_POST['business-type']) && $_POST['business-type'] != 'on') { // on is default val for 'all'
            $args['meta_query'] = [
                [
                    'key'     => 'business_type',
                    'value'   => $_POST['business-type'],
                ],
            ];
        }

        $args['meta_key'] = 'featured';
        $args['orderby'] = ['meta_value' => 'DESC', 'title' => 'ASC'];

        query_posts($args);
        ?>
        <script>
            var max_page = <?= count(query_posts($args)); ?>;
        </script>
        <?php
        if (have_posts()) {
            while (have_posts()) {
                the_post();
                get_template_part('templates/business/content');
            }
        } else {
            echo '<div class="no-results-found">There were no results found.</div>';
        }
        die;
    }

    public static function loadGlobalVar()
    {
        global $wp_query;
        ?>
        <script type="text/javascript">
            const ajaxurl = <?= json_encode(admin_url("admin-ajax.php")); ?>;
            const ajaxnonce = <?= json_encode(wp_create_nonce("itr_ajax_nonce")); ?>;
            var posts = <?= json_encode($wp_query->query_vars); ?>;
        </script><?php
    }

    public static function orderBusinesses($query)
    {
        if (is_post_type_archive('business') && !is_admin() && $query->is_main_query()) {
            $query->set('meta_key', 'featured');
            $query->set('orderby',['featured' => 'DESC', 'title' => 'ASC']);
        }
    }


}

==> blue2-buy-angus-theme-1.24.0-5b5167.tar: src/Controllers/BusinessController.php <==
<?php

namespace Blue2\Scruffy\Controllers;

class BusinessController
{
    public function __construct()
    {
        $this->registerActions();
        $this->registerTaxonomies();
    }

    private function registerActions() {
        add_action('wp_head', [$this, 'loadGlobalVar']);
        add_action('wp_ajax_loadBusiness', [$this, 'loadBusinessAjaxHandler']);
        add_action('wp_ajax_nopriv_loadBusiness', [$this, 'loadBusinessAjaxHandler']);
        add_action('pre_get_posts', [$this, 'orderBusinesses']);
    }

    public static function registerTaxonomies()
    {
        $businessCategory = new \Blue2\Common\Taxonomy(
            "business-category",
            "Business Category",
            "Business Categories",
            "business",
            [
                'public' => true,
                'show_in_menu' => true,
                'show_admin_column' => true
            ]
        );

        $accessibilityCategory = new \Blue2\Common\Taxonomy(
            "accessibility-category",
            "Accessibility Category",
            "Accessibility Categories",
            "business",
            [
                'public' => true,
                'show_in_menu' => true,
                'show_admin_column' => true
            ]
        );

    }

    public function loadBusinessAjaxHandler()
    {
        $args['post_type'] = 'business';
        $args['post_status'] = 'publish';

        if (isset($_POST['searchPosts'])) {
            $args['s'] = $_POST['searchPosts'];
        }
        $args['tax_query'] = ['relation' => 'AND'];

        if (isset($_POST['business']) && $_POST['business'] != 'all' && $_POST['business'] != '') {
            $args['tax_query'][] = [
                [
                    'taxonomy' => 'business-category',
                    'field' => 'id',
                    'terms' => explode(",", $_POST['business']),
                ],
            ];
        }

        if (isset($_POST['accessibility']) && $_POST['accessibility'] != 'all' && $_POST['accessibility'] != '') {
            $args['tax_query'][] = [
                [
                    'taxonomy' => 'accessibility-category',
                    'field' => 'id',
                    'terms' => explode(",", $_POST['accessibility']),
                ],
            ];
        }

        if (isset($_POST['business-type']) && $_POST['business-type'] != 'on') { // on is default val for 'all'
            $args['meta_query'] = [
                [
                    'key'     => 'business_type',
                    'value'   => $_POST['business-type'],
                ],
            ];
        }

        $args['meta_key'] = 'featured';
        $args['orderby'] = ['meta_value' => 'DESC', 'title' => 'ASC'];

        query_posts($args);
        ?>
        <script>
            var max_page = <?= count(query_posts($args)); ?>;
        </script>
        <?php
        if (have_posts()) {
            while (have_posts()) {
                the_post();
                get_template_part('templates/business/content');
            }
        } else {
            echo '<div class="no-results-found">There were no results found.</div>';
        }
        die;
    }

    public static function loadGlobalVar()
    {
        global $wp_query;
        ?>
        <script type="text/javascript">
            const ajaxurl = <?= json_encode(admin_url("admin-ajax.php")); ?>;
            const ajaxnonce = <?= json_encode(wp_create_nonce("itr_ajax_nonce")); ?>;
            var posts = <?= json_encode($wp_query->query_vars); ?>;
        </script><?php
    }

    public static function orderBusinesses($query)
    {
        if (is_post_type_archive('business') && !is_admin() && $query->is_main_query()) {
            $query->set('meta_key', 'featured');
            $query->set('orderby',['featured' => 'DESC', 'title' => 'ASC']);
        }
    }


}
